@@ -19,7 +19,9 @@
 #include <queue>
 
 #include <ignition/common/Console.hh>
+#include <ignition/common/Filesystem.hh>
 #include <ignition/common/SignalHandler.hh>
+#include <ignition/common/StringUtils.hh>
 #include <ignition/common/SystemPaths.hh>
 #include <ignition/common/Util.hh>
 
@@ -179,7 +181,7 @@ QQmlApplicationEngine *Application::Engine() const
 }
 
 /////////////////////////////////////////////////
-Application *ignition::gui::App()
+Application *gui::App()
 {
   return qobject_cast<Application *>(qGuiApp);
 }
@@ -222,24 +224,50 @@ bool Application::LoadConfig(const std::string &_config)
     return false;
   }
 
+  std::string configFull = _config;
+
+  // Check if the passed in config file exists.
+  // (If the default config path doesn't exist yet, it's expected behavior.
+  // It will be created the first time the user presses "Save configuration".)
+  if (!common::exists(configFull) && (configFull != this->DefaultConfigPath()))
+  {
+    // If not, then check environment variable
+    std::string configPathEnv;
+    common::env("GZ_GUI_RESOURCE_PATH", configPathEnv);
+
+    if (!configPathEnv.empty())
+    {
+      std::vector<std::string> parentPaths = common::Split(configPathEnv, ':');
+      for (auto parentPath : parentPaths)
+      {
+        std::string tempPath = common::joinPaths(parentPath, configFull);
+        if (common::exists(tempPath))
+        {
+          configFull = tempPath;
+          break;
+        }
+      }
+    }
+  }
+
   // Use tinyxml to read config
   tinyxml2::XMLDocument doc;
-  auto success = !doc.LoadFile(_config.c_str());
+  auto success = !doc.LoadFile(configFull.c_str());
   if (!success)
   {
     // We do not show an error message if the default config path doesn't exist
     // yet. It's expected behavior, it will be created the first time the user
     // presses "Save configuration".
-    if (_config != this->DefaultConfigPath())
+    if (configFull != this->DefaultConfigPath())
     {
-      ignerr << "Failed to load file [" << _config << "]: XMLError"
+      ignerr << "Failed to load file [" << configFull << "]: XMLError"
              << std::endl;
     }
 
     return false;
   }
 
-  ignmsg << "Loading config [" << _config << "]" << std::endl;
+  ignmsg << "Loading config [" << configFull << "]" << std::endl;
 
   // Clear all previous plugins
   auto plugins = this->dataPtr->mainWin->findChildren<Plugin *>();
@@ -389,6 +417,12 @@ std::string Application::DefaultConfigPath()
 bool Application::LoadPlugin(const std::string &_filename,
     const tinyxml2::XMLElement *_pluginElem)
 {
+  if (_filename.empty())
+  {
+    ignerr << "Trying to load plugin with empty filename." << std::endl;
+    return false;
+  }
+
   igndbg << "Loading plugin [" << _filename << "]" << std::endl;
 
   common::SystemPaths systemPaths;
@@ -424,7 +458,7 @@ bool Application::LoadPlugin(const std::string &_filename,
   }
 
   // Go over all plugin names and get the first one that implements the
-  // ignition::gui::Plugin interface
+  // gui::Plugin interface
   plugin::PluginPtr commonPlugin;
   std::shared_ptr<gui::Plugin> plugin{nullptr};
   for (auto pluginName : pluginNames)
@@ -433,7 +467,7 @@ bool Application::LoadPlugin(const std::string &_filename,
     if (!commonPlugin)
       continue;
 
-    plugin = commonPlugin->QueryInterfaceSharedPtr<ignition::gui::Plugin>();
+    plugin = commonPlugin->QueryInterfaceSharedPtr<gui::Plugin>();
     if (plugin)
       break;
   }
@@ -454,7 +488,7 @@ bool Application::LoadPlugin(const std::string &_filename,
   if (!plugin)
   {
     ignerr << "Failed to load plugin [" << _filename <<
-              "] : couldn't get [ignition::gui::Plugin] interface."
+              "] : couldn't get [gui::Plugin] interface."
            << std::endl;
     return false;
   }
@@ -509,6 +543,12 @@ std::shared_ptr<Plugin> Application::PluginByName(
   return nullptr;
 }
 
+/////////////////////////////////////////////////
+bool Application::CreateMainWindow()
+{
+  return this->InitializeMainWindow();
+}
+
 /////////////////////////////////////////////////
 bool Application::InitializeMainWindow()
 {
