@@ -749,8 +749,8 @@ rendering::GeometryPtr SceneManager::LoadGeometry(const msgs::Geometry &_msg,
     // Assume absolute path to mesh file
     descriptor.meshName = _msg.mesh().filename();
 
-    ignition::common::MeshManager* meshManager =
-        ignition::common::MeshManager::Instance();
+    common::MeshManager* meshManager =
+        common::MeshManager::Instance();
     descriptor.mesh = meshManager->Load(descriptor.meshName);
     geom = this->scene->CreateMesh(descriptor);
 
@@ -903,11 +903,11 @@ void IgnRenderer::Render()
   // update and render to texture
   this->dataPtr->camera->Update();
 
-  if (ignition::gui::App())
+  if (gui::App())
   {
-    ignition::gui::App()->sendEvent(
-        ignition::gui::App()->findChild<ignition::gui::MainWindow *>(),
-        new gui::events::Render());
+    gui::App()->sendEvent(
+        gui::App()->findChild<MainWindow *>(),
+        new events::Render());
   }
 }
 
@@ -918,6 +918,8 @@ void IgnRenderer::HandleMouseEvent()
   this->BroadcastHoverPos();
   this->BroadcastLeftClick();
   this->BroadcastRightClick();
+  this->BroadcastKeyPress();
+  this->BroadcastKeyRelease();
   this->HandleMouseViewControl();
 }
 
@@ -1010,7 +1012,7 @@ void IgnRenderer::HandleKeyRelease(QKeyEvent *_e)
 
   std::lock_guard<std::mutex> lock(this->dataPtr->mutex);
 
-  this->dataPtr->keyEvent.SetKey(0);
+  this->dataPtr->keyEvent.SetKey(_e->key());
 
   this->dataPtr->keyEvent.SetControl(
     (_e->modifiers() & Qt::ControlModifier)
@@ -1056,7 +1058,10 @@ void IgnRenderer::BroadcastLeftClick()
   auto pos = this->ScreenToScene(this->dataPtr->mouseEvent.Pos());
 
   events::LeftClickToScene leftClickToSceneEvent(pos);
+  events::LeftClickOnScene leftClickOnSceneEvent(this->dataPtr->mouseEvent);
+
   App()->sendEvent(App()->findChild<MainWindow *>(), &leftClickToSceneEvent);
+  App()->sendEvent(App()->findChild<MainWindow *>(), &leftClickOnSceneEvent);
 }
 
 /////////////////////////////////////////////////
@@ -1075,7 +1080,32 @@ void IgnRenderer::BroadcastRightClick()
   auto pos = this->ScreenToScene(this->dataPtr->mouseEvent.Pos());
 
   events::RightClickToScene rightClickToSceneEvent(pos);
+  events::RightClickOnScene rightClickOnSceneEvent(this->dataPtr->mouseEvent);
+
   App()->sendEvent(App()->findChild<MainWindow *>(), &rightClickToSceneEvent);
+  App()->sendEvent(App()->findChild<MainWindow *>(), &rightClickOnSceneEvent);
+}
+
+/////////////////////////////////////////////////
+void IgnRenderer::BroadcastKeyRelease()
+{
+  if (this->dataPtr->keyEvent.Type() == common::KeyEvent::RELEASE)
+  {
+    events::KeyReleaseOnScene keyRelease(this->dataPtr->keyEvent);
+    App()->sendEvent(App()->findChild<MainWindow *>(), &keyRelease);
+    this->dataPtr->keyEvent.SetType(common::KeyEvent::NO_EVENT);
+  }
+}
+
+/////////////////////////////////////////////////
+void IgnRenderer::BroadcastKeyPress()
+{
+  if (this->dataPtr->keyEvent.Type() == common::KeyEvent::PRESS)
+  {
+    events::KeyPressOnScene keyPress(this->dataPtr->keyEvent);
+    App()->sendEvent(App()->findChild<MainWindow *>(), &keyPress);
+    this->dataPtr->keyEvent.SetType(common::KeyEvent::NO_EVENT);
+  }
 }
 
 /////////////////////////////////////////////////
@@ -1093,6 +1123,9 @@ std::string IgnRenderer::Initialize()
   {
     std::map<std::string, std::string> params;
     params["useCurrentGLContext"] = "1";
+    params["winID"] = std::to_string(
+        ignition::gui::App()->findChild<ignition::gui::MainWindow *>()->
+        QuickWindow()->winId());
     engine = rendering::engine(this->engineName, params);
   }
   else
@@ -1542,6 +1575,10 @@ void RenderWindowItem::SetSceneTopic(const std::string &_topic)
 Scene3D::Scene3D()
   : Plugin(), dataPtr(new Scene3DPrivate)
 {
+  ignwarn << "This plugin is deprecated on ign-gui v6 and will be removed on "
+          << "ign-gui v7. Use MinimalScene + TransportSceneManager instead."
+          << std::endl;
+
   qmlRegisterType<RenderWindowItem>("RenderWindow", 1, 0, "RenderWindow");
 }
 
@@ -1647,7 +1684,7 @@ void Scene3D::LoadConfig(const tinyxml2::XMLElement *_pluginElem)
 }
 
 /////////////////////////////////////////////////
-void RenderWindowItem::OnHovered(const ignition::math::Vector2i &_hoverPos)
+void RenderWindowItem::OnHovered(const math::Vector2i &_hoverPos)
 {
   this->dataPtr->renderThread->ignRenderer.NewHoverEvent(_hoverPos);
 }
@@ -1708,6 +1745,18 @@ void RenderWindowItem::wheelEvent(QWheelEvent *_e)
       this->dataPtr->mouseEvent, math::Vector2d(scroll, scroll));
 }
 
+////////////////////////////////////////////////
+void RenderWindowItem::keyPressEvent(QKeyEvent *_event)
+{
+  this->HandleKeyPress(_event);
+}
+
+////////////////////////////////////////////////
+void RenderWindowItem::keyReleaseEvent(QKeyEvent *_event)
+{
+  this->HandleKeyRelease(_event);
+}
+
 ////////////////////////////////////////////////
 void RenderWindowItem::HandleKeyPress(QKeyEvent *_e)
 {
@@ -1774,5 +1823,5 @@ void Scene3D::SetLoadingError(const QString &_loadingError)
 }
 
 // Register this plugin
-IGNITION_ADD_PLUGIN(ignition::gui::plugins::Scene3D,
-                    ignition::gui::Plugin)
+IGNITION_ADD_PLUGIN(Scene3D,
+                    gui::Plugin)
