@@ -65,6 +65,7 @@ TEST(Scene3DTest, IGN_UTILS_TEST_ENABLED_ONLY_ON_LINUX(Load))
 
   // Cleanup
   plugins.clear();
+  win->QuickWindow()->close();
 }
 
 /////////////////////////////////////////////////
@@ -127,6 +128,17 @@ TEST(Scene3DTest, IGN_UTILS_TEST_ENABLED_ONLY_ON_LINUX(Config))
   ASSERT_NE(nullptr, camera);
 
   EXPECT_EQ(math::Pose3d(1, 2, 3, 0, 0, 1.57), camera->WorldPose());
+
+  // Cleanup
+  auto plugins = win->findChildren<Plugin *>();
+  for (auto & p : plugins)
+  {
+    auto pluginName = p->CardItem()->objectName();
+    app.RemovePlugin(pluginName.toStdString());
+  }
+  win->QuickWindow()->close();
+  engine->DestroyScene(scene);
+  rendering::unloadEngine(engine->Name());
 }
 
 /////////////////////////////////////////////////
@@ -163,10 +175,26 @@ TEST(Scene3DTest, IGN_UTILS_TEST_ENABLED_ONLY_ON_LINUX(Events))
   bool receivedRenderEvent{false};
   bool receivedRightEvent{false};
   bool receivedLeftEvent{false};
+  bool receivedRightAltEvent{false};
+  bool receivedRightControlEvent{false};
+  bool receivedRightShiftEvent{false};
+  bool receivedLeftAltEvent{false};
+  bool receivedLeftControlEvent{false};
+  bool receivedLeftShiftEvent{false};
   bool receivedHoverEvent{false};
+  bool receivedKeyPressEvent{false};
+  bool receivedKeyPressEventAlt{false};
+  bool receivedKeyPressEventControl{false};
+  bool receivedKeyPressEventShift{false};
+  bool receivedKeyReleaseEvent{false};
+  bool receivedKeyReleaseEventAlt{false};
+  bool receivedKeyReleaseEventControl{false};
+  bool receivedKeyReleaseEventShift{false};
 
   // Position vectors reported by click events
   math::Vector3d leftClickPoint, rightClickPoint;
+  // key pressed or released
+  int keyPressedValue, keyReleasedValue;
 
   // Helper to filter events
   auto testHelper = std::make_unique<TestHelper>();
@@ -182,38 +210,96 @@ TEST(Scene3DTest, IGN_UTILS_TEST_ENABLED_ONLY_ON_LINUX(Events))
       auto rightClickToScene = static_cast<events::RightClickToScene*>(_event);
       rightClickPoint = rightClickToScene->Point();
     }
+    else if (_event->type() == events::RightClickOnScene::kType)
+    {
+      auto rightClickOnScene = static_cast<events::RightClickOnScene*>(_event);
+      receivedRightAltEvent = rightClickOnScene->Mouse().Alt();
+      receivedRightControlEvent = rightClickOnScene->Mouse().Control();
+      receivedRightShiftEvent = rightClickOnScene->Mouse().Shift();
+    }
     else if (_event->type() == events::LeftClickToScene::kType)
     {
       receivedLeftEvent = true;
       auto leftClickToScene = static_cast<events::LeftClickToScene*>(_event);
       leftClickPoint = leftClickToScene->Point();
     }
+    else if (_event->type() == events::LeftClickOnScene::kType)
+    {
+      auto leftClickOnScene = static_cast<events::LeftClickOnScene*>(_event);
+      receivedLeftAltEvent = leftClickOnScene->Mouse().Alt();
+      receivedLeftControlEvent = leftClickOnScene->Mouse().Control();
+      receivedLeftShiftEvent = leftClickOnScene->Mouse().Shift();
+    }
     else if (_event->type() == events::HoverToScene::kType)
     {
       receivedHoverEvent = true;
     }
+    else if (_event->type() == events::KeyReleaseOnScene::kType)
+    {
+      receivedKeyReleaseEvent = true;
+      auto keyReleased = static_cast<events::KeyReleaseOnScene*>(_event);
+      keyReleasedValue = keyReleased->Key().Key();
+      receivedKeyReleaseEventAlt = keyReleased->Key().Alt();
+      receivedKeyReleaseEventControl = keyReleased->Key().Control();
+      receivedKeyReleaseEventShift = keyReleased->Key().Shift();
+    }
+    else if (_event->type() == events::KeyPressOnScene::kType)
+    {
+      receivedKeyPressEvent = true;
+      auto keyPress = static_cast<events::KeyPressOnScene*>(_event);
+      keyPressedValue = keyPress->Key().Key();
+      receivedKeyPressEventAlt = keyPress->Key().Alt();
+      receivedKeyPressEventControl = keyPress->Key().Control();
+      receivedKeyPressEventShift = keyPress->Key().Shift();
+    }
   };
 
   int sleep = 0;
   int maxSleep = 30;
-  while ((!receivedRenderEvent || !receivedRightEvent ||
-    !receivedLeftEvent || !receivedHoverEvent) && sleep < maxSleep)
+  while (!receivedRenderEvent && sleep < maxSleep)
   {
     std::this_thread::sleep_for(std::chrono::milliseconds(100));
     QCoreApplication::processEvents();
-
+    sleep++;
+  }
+  sleep = 0;
+  while (!receivedHoverEvent && sleep < maxSleep)
+  {
     QTest::mouseMove(win->QuickWindow(), QPoint(70, 100), -1);
     std::this_thread::sleep_for(std::chrono::milliseconds(100));
     QCoreApplication::processEvents();
-
-    QTest::mouseClick(win->QuickWindow(), Qt::RightButton, Qt::NoModifier);
+    sleep++;
+  }
+  sleep = 0;
+  while (!receivedRightEvent && sleep < maxSleep)
+  {
+    QTest::mouseClick(win->QuickWindow(), Qt::RightButton, Qt::ShiftModifier);
     std::this_thread::sleep_for(std::chrono::milliseconds(100));
     QCoreApplication::processEvents();
-
-    QTest::mouseClick(win->QuickWindow(), Qt::LeftButton, Qt::NoModifier);
+    sleep++;
+  }
+  sleep = 0;
+  while (!receivedLeftEvent && sleep < maxSleep)
+  {
+    QTest::mouseClick(win->QuickWindow(), Qt::LeftButton, Qt::AltModifier);
+    std::this_thread::sleep_for(std::chrono::milliseconds(100));
+    QCoreApplication::processEvents();
+    sleep++;
+  }
+  sleep = 0;
+  while (!receivedKeyPressEvent && sleep < maxSleep)
+  {
+    QTest::keyPress(win->QuickWindow(), Qt::Key_A, Qt::AltModifier);
+    std::this_thread::sleep_for(std::chrono::milliseconds(100));
+    QCoreApplication::processEvents();
+    sleep++;
+  }
+  sleep = 0;
+  while (!receivedKeyReleaseEvent && sleep < maxSleep)
+  {
+    QTest::keyRelease(win->QuickWindow(), Qt::Key_Escape, Qt::NoModifier);
     std::this_thread::sleep_for(std::chrono::milliseconds(100));
     QCoreApplication::processEvents();
-
     sleep++;
   }
 
@@ -221,9 +307,35 @@ TEST(Scene3DTest, IGN_UTILS_TEST_ENABLED_ONLY_ON_LINUX(Events))
   EXPECT_TRUE(receivedLeftEvent);
   EXPECT_TRUE(receivedRightEvent);
   EXPECT_TRUE(receivedHoverEvent);
+  EXPECT_TRUE(receivedLeftAltEvent);
+  EXPECT_FALSE(receivedLeftControlEvent);
+  EXPECT_FALSE(receivedLeftShiftEvent);
+  EXPECT_FALSE(receivedRightAltEvent);
+  EXPECT_FALSE(receivedRightControlEvent);
+  EXPECT_TRUE(receivedRightShiftEvent);
 
   EXPECT_EQ(leftClickPoint, rightClickPoint);
   EXPECT_NEAR(1.0, leftClickPoint.X(), 1e-3);
   EXPECT_NEAR(11.942695, leftClickPoint.Y(), 1e-1);
   EXPECT_NEAR(4.159424, leftClickPoint.Z(), 0.5);
+
+  EXPECT_TRUE(receivedKeyReleaseEvent);
+  EXPECT_FALSE(receivedKeyReleaseEventAlt);
+  EXPECT_FALSE(receivedKeyReleaseEventControl);
+  EXPECT_FALSE(receivedKeyReleaseEventShift);
+  EXPECT_EQ(Qt::Key_Escape, keyReleasedValue);
+  EXPECT_TRUE(receivedKeyPressEvent);
+  EXPECT_TRUE(receivedKeyPressEventAlt);
+  EXPECT_FALSE(receivedKeyPressEventControl);
+  EXPECT_FALSE(receivedKeyPressEventShift);
+  EXPECT_EQ(Qt::Key_A, keyPressedValue);
+
+  // Cleanups
+  auto plugins = win->findChildren<Plugin *>();
+  for (auto & p : plugins)
+  {
+    auto pluginName = p->CardItem()->objectName();
+    app.RemovePlugin(pluginName.toStdString());
+  }
+  win->QuickWindow()->close();
 }
